summaryrefslogtreecommitdiff
path: root/tests/test-pull-repeated.sh
diff options
context:
space:
mode:
authorRicardo Noriega <rnoriega@redhat.com>2022-11-09 10:52:16 +0100
committerRicardo Noriega <rnoriega@redhat.com>2022-11-09 11:20:10 +0100
commit6ce2324e4a0e75d1546837b606efad18bb71a59f (patch)
treec2b2fa03edfaab449001fa199d1a57bf2237a0e4 /tests/test-pull-repeated.sh
parent722be7e3d74f095db749a9c93df4c618f67371bd (diff)
downloadostree-6ce2324e4a0e75d1546837b606efad18bb71a59f.tar.gz
Add tests for cases under random 500s
Signed-off-by: Ricardo Noriega <rnoriega@redhat.com>
Diffstat (limited to 'tests/test-pull-repeated.sh')
-rwxr-xr-xtests/test-pull-repeated.sh44
1 files changed, 38 insertions, 6 deletions
diff --git a/tests/test-pull-repeated.sh b/tests/test-pull-repeated.sh
index 4c321618..7f724c95 100755
--- a/tests/test-pull-repeated.sh
+++ b/tests/test-pull-repeated.sh
@@ -26,18 +26,32 @@ if has_gpgme; then
COMMIT_SIGN="--gpg-homedir=${TEST_GPG_KEYHOME} --gpg-sign=${TEST_GPG_KEYID_1}"
fi
-echo "1..4"
+echo "1..6"
-# Test pulling from a repo which gives error 500 (internal server error) a lot of the time.
+# Sanity check with no network retries and 500s given, pull should fail.
+rm ostree-srv httpd repo -rf
+setup_fake_remote_repo1 "archive" "${COMMIT_SIGN}" --random-500s=99
+
+pushd ${test_tmpdir}
+ostree_repo_init repo --mode=archive
+${CMD_PREFIX} ostree --repo=repo remote add --set=gpg-verify=false origin $(cat httpd-address)/ostree/gnomerepo
+assert_fail ${CMD_PREFIX} ostree --repo=repo pull --mirror origin --network-retries=0 main 2>err.txt
+assert_file_has_content err.txt "\(500.*Internal Server Error\)\|\(HTTP 500\)"
+
+popd
+echo "ok no retries after a 500"
+
+# Test pulling a repo which gives error 500 (internal server error) a lot of the time.
+rm ostree-srv httpd repo -rf
setup_fake_remote_repo1 "archive" "${COMMIT_SIGN}" --random-500s=50
pushd ${test_tmpdir}
ostree_repo_init repo --mode=archive
${CMD_PREFIX} ostree --repo=repo remote add --set=gpg-verify=false origin $(cat httpd-address)/ostree/gnomerepo
-for x in $(seq 200); do
- if ${CMD_PREFIX} ostree --repo=repo pull --mirror origin main 2>err.txt; then
- echo "Success on iteration ${x}"
- break;
+for x in $(seq 40); do
+ if ${CMD_PREFIX} ostree --repo=repo pull --mirror origin --network-retries=2 main 2>err.txt; then
+ echo "Success on iteration ${x}"
+ break;
fi
assert_file_has_content err.txt "\(500.*Internal Server Error\)\|\(HTTP 500\)"
done
@@ -48,6 +62,24 @@ ${CMD_PREFIX} ostree --repo=repo rev-parse main
popd
echo "ok repeated pull after 500s"
+# Test pulling a repo that gives 408s a lot of the time, with many network retries.
+rm ostree-srv httpd repo -rf
+setup_fake_remote_repo1 "archive" "${COMMIT_SIGN}" --random-500s=50
+
+pushd ${test_tmpdir}
+ostree_repo_init repo --mode=archive
+${CMD_PREFIX} ostree --repo=repo remote add --set=gpg-verify=false origin $(cat httpd-address)/ostree/gnomerepo
+
+# We limit 500s above to 100, so 100 retries should be enough always.
+${CMD_PREFIX} ostree --repo=repo pull --mirror origin --network-retries=100 main
+echo "Success with big number of network retries"
+
+${CMD_PREFIX} ostree --repo=repo fsck
+${CMD_PREFIX} ostree --repo=repo rev-parse main
+
+popd
+echo "ok big number of retries with one 500s"
+
# Sanity check with no network retries and 408s given, pull should fail.
rm ostree-srv httpd repo -rf
setup_fake_remote_repo1 "archive" "${COMMIT_SIGN}" --random-408s=99